# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import winrt.system
from winrt import _winrt_windows_ui_notifications_preview

__all__ = [
    "ToastOcclusionManagerPreview",
]

ToastOcclusionManagerPreview = _winrt_windows_ui_notifications_preview.ToastOcclusionManagerPreview
